pub struct LogPlugin {
pub filter: String,
pub level: LogLevel,
pub custom_layer: fn(app: &mut App) -> Option<Box<dyn Layer<Registry> + Send + Sync + 'static>>,
pub fmt_layer: fn(app: &mut App) -> Option<Box<dyn Layer<Layered<EnvFilter, Layered<Option<Box<dyn Layer<Registry> + Send + Sync>>, Registry>>> + Send + Sync + 'static>>,
pub log_file: PathBuf,
}Expand description
Plugin that configures logging for WaterDropEngine applications.
Configuration
The RUST_LOG environment variable overrides plugin settings and uses [EnvFilter] syntax.
Set NO_COLOR=1 to disable colored output (see no-color.org).
Log Levels
Available log levels (most to least important):
error!()- Critical failureswarn!()- Important warningsinfo!()- General informationdebug!()- Debug informationtrace!()- Verbose tracing
Fields
filter: StringFilters logs using the [EnvFilter] format
level: LogLevelFilters out logs that are “less than” the given level. This can be further filtered using the filter setting.
custom_layer: fn(app: &mut App) -> Option<Box<dyn Layer<Registry> + Send + Sync + 'static>>Optionally add an extra [Layer] to the tracing subscriber.
fmt_layer: fn(app: &mut App) -> Option<Box<dyn Layer<Layered<EnvFilter, Layered<Option<Box<dyn Layer<Registry> + Send + Sync>>, Registry>>> + Send + Sync + 'static>>Override the default [tracing_subscriber::fmt::Layer] with a custom one.
For example, you can use [tracing_subscriber::fmt::Layer::without_time] to remove the
timestamp from the log output.
log_file: PathBufPath of the file logs are written to. The previous log file, if any, is renamed
alongside it with a -old suffix before its extension (e.g. log.txt -> log-old.txt).
Defaults to <temp_dir>/waterdropengine/log.txt.
Implementations
Sourceimpl LogPlugin
impl LogPlugin
Sourcepub fn auto_level(self) -> Self
pub fn auto_level(self) -> Self
Sets the log level based on debug/release mode.
Sourcepub fn with_crate_level(self, target: &str, level: LogLevel) -> Self
pub fn with_crate_level(self, target: &str, level: LogLevel) -> Self
Overrides the log level for a specific crate/module target, regardless of the global level.
This is useful to keep the engine’s own logs quiet (e.g. LogLevel::INFO) while enabling
more verbose logging (e.g. LogLevel::DEBUG) for your own game/application crate.
target should be the crate’s module path as used by tracing (i.e. the crate name with
- replaced by _), such as "my_game".